"""
    The package description.

"""

# Package information
# ===================

__version__ = "0.0.5"
__project__ = "peewee_migrate"
__author__ = "Kirill Klenov <horneds@gmail.com>"
__license__ = "BSD"
